isSmallerThan method
Create a filter to check if the column is small than a value
Implementation
@pragma('drift:v3-rename', 'isLessThan')
Expression<bool> isSmallerThan(T value) =>
$composableFilter(column.isSmallerThanValue(value));
Create a filter to check if the column is small than a value
@pragma('drift:v3-rename', 'isLessThan')
Expression<bool> isSmallerThan(T value) =>
$composableFilter(column.isSmallerThanValue(value));