RowIdExtension extension
Extension to use the rowid of a table in Dart queries.
Properties
-
rowId
→ Expression<
int> -
Available on TableInfo<
In sqlite, each table that hasn't been created with theTable, dynamic> , provided by the RowIdExtension extensionWITHOUT ROWIDmodifier has a row id. When the table has a single primary key column which is an integer, that column is an alias to the row id in sqlite3.no setter