extensions/fts5 library

Bindings to the fts5 sqlite extension, which provides full-text search functionality.

The extension members in this library assume that the table they're used with was created as an fts5 virtual table. In a drift file, such tables are declared like this:

CREATE VIRTUAL TABLE email USING fts5(sender, title, body);

With that table, a full-text search could look like this:

final query = select(emails)
  ..where(emails.match('hello NEAR world'))
  ..orderBy([(u) => OrderingTerm(expression: emails.rank)]);

Extensions

Fts5Extensions on VirtualTableInfo<Table, dynamic>
Support for full-text search queries on fts5 tables.