Fts5Extensions extension

Support for full-text search queries on fts5 tables.

See the sqlite documentation for details on the fts5 query syntax and its auxiliary functions.

on

Properties

rank Expression<double>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

The relevance of a match found by an fts5 query, as computed by bm25 with default weights.
no setter

Methods

bm25({List<double> weights = const []}) Expression<double>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

The bm25 relevance of a match found by an fts5 query.
highlight(GeneratedColumn<String> column, {required String before, required String after}) Expression<String>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

Returns the text of column with a match found by an fts5 query wrapped in before and after.
match(String query) Expression<bool>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

Whether this table contains a row matching the fts5 query string.
matchExp(Expression<String> expression) Expression<bool>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

Whether this table contains a row matching the fts5 query given as an sql expression.
snippet(GeneratedColumn<String> column, {required String before, required String after, required String ellipsis, required int tokenCount}) Expression<String>

Available on VirtualTableInfo<Table, dynamic>, provided by the Fts5Extensions extension

Like highlight, but only reports a tokenCount tokens of text around each match, separated by ellipsis when text was omitted.