match method

Expression<bool> match(
  1. String query
)

Whether this table contains a row matching the fts5 query string.

The query uses the fts5 query syntax, it is sent to the database as a variable so that it's safe to construct it from user input.

select(emails)..where(emails.match('hello NEAR world'));

To restrict a search to individual columns, use the column filter syntax of the fts5 query language, e.g. emails.match('{title body} : hello').

See also:

  • matchExp, which is like this method but supports arbitrary expressions as the query.

Implementation

Expression<bool> match(String query) => matchExp(Variable.withString(query));