readWithConverter<D, S extends Object> method
Reads a column that has a type converter applied to it from the row.
This calls read internally, which reads the column but without applying a type converter.
Implementation
D? readWithConverter<D, S extends Object>(
GeneratedColumnWithTypeConverter<D, S> column,
) {
return NullAwareTypeConverter.wrapFromSql(
column.converter,
read<S>(column),
);
}