Fts5Extensions extension
Support for full-text search queries on fts5 tables.
See the sqlite documentation for details on the fts5 query syntax and its auxiliary functions.
- on
-
- VirtualTableInfo<
Table, dynamic>
- VirtualTableInfo<
Properties
-
rank
→ Expression<
double> -
Available on VirtualTableInfo<
The relevance of a match found by an fts5 query, as computed by bm25 with default weights.Table, dynamic> , provided by the Fts5Extensions extensionno setter
Methods
-
bm25(
{List< double> weights = const []}) → Expression<double> -
Available on VirtualTableInfo<
The bm25 relevance of a match found by an fts5 query.Table, dynamic> , provided by the Fts5Extensions extension -
highlight(
GeneratedColumn< String> column, {required String before, required String after}) → Expression<String> -
Available on VirtualTableInfo<
Returns the text ofTable, dynamic> , provided by the Fts5Extensions extensioncolumnwith a match found by an fts5 query wrapped inbeforeandafter. -
match(
String query) → Expression< bool> -
Available on VirtualTableInfo<
Whether this table contains a row matching the fts5Table, dynamic> , provided by the Fts5Extensions extensionquerystring. -
matchExp(
Expression< String> expression) → Expression<bool> -
Available on VirtualTableInfo<
Whether this table contains a row matching the fts5 query given as an sqlTable, dynamic> , provided by the Fts5Extensions extensionexpression. -
snippet(
GeneratedColumn< String> column, {required String before, required String after, required String ellipsis, required int tokenCount}) → Expression<String> -
Available on VirtualTableInfo<
Like highlight, but only reports aTable, dynamic> , provided by the Fts5Extensions extensiontokenCounttokens of text around each match, separated byellipsiswhen text was omitted.